Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(274)

Unified Diff: chrome/browser/ui/views/autofill/autofill_popup_base_view.h

Issue 2727233003: Uses child views in Autofill Popup so we can trigger (Closed)
Patch Set: (int) to NSInteger Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/autofill/autofill_popup_base_view.h
diff --git a/chrome/browser/ui/views/autofill/autofill_popup_base_view.h b/chrome/browser/ui/views/autofill/autofill_popup_base_view.h
index 2550510cd6cbdf952de8300d3e601d78e1cae71f..181b1428a6523042253fa0726d78efb127436796 100644
--- a/chrome/browser/ui/views/autofill/autofill_popup_base_view.h
+++ b/chrome/browser/ui/views/autofill/autofill_popup_base_view.h
@@ -35,8 +35,8 @@ class AutofillPopupBaseView : public views::WidgetDelegateView,
// Hide the widget and delete |this|.
void DoHide();
- // Update size of popup and paint.
- void DoUpdateBoundsAndRedrawPopup();
+ // Update size of popup and paint (virtual for testing).
+ virtual void DoUpdateBoundsAndRedrawPopup();
private:
friend class AutofillPopupBaseViewTest;

Powered by Google App Engine
This is Rietveld 408576698